#!/usr/bin/env python3

#TODO: """DocString if there is one"""

import io
import os

from epyqlib.iopoint import IoPoint
from PyQt5 import uic
from PyQt5.QtCore import pyqtProperty, QFile, QFileInfo, QTextStream
from PyQt5.QtGui import QColor
from PyQt5.QtWidgets import QLabel, QHBoxLayout, QWidget

# See file COPYING in this source tree
__copyright__ = 'Copyright 2016, EPC Power Corp.'
__license__ = 'GPLv2+'


class IoGroup(QWidget):
    def __init__(self, parent=None, in_designer=False):
        QWidget.__init__(self, parent=parent)

        self.in_designer = in_designer

        ui = os.path.join(QFileInfo.absolutePath(QFileInfo(__file__)),
                          'iogroup.ui')

        # TODO: CAMPid 9549757292917394095482739548437597676742
        if not QFileInfo(ui).isAbsolute():
            ui_file = os.path.join(
                QFileInfo.absolutePath(QFileInfo(__file__)), ui)
        else:
            ui_file = ui
        ui_file = QFile(ui_file)
        ui_file.open(QFile.ReadOnly | QFile.Text)
        ts = QTextStream(ui_file)
        sio = io.StringIO(ts.readAll())
        self.ui = uic.loadUi(sio, self)

        self._status_frame = ''
        self._status_signal_format = ''
        self._set_frame = ''
        self._set_signal_format = ''
        self._override_frame = ''
        self._override_signal_format = ''

        self._quantity = 0
        self._tx = True

        self.points = []

    @pyqtProperty(bool)
    def tx(self):
        return self._tx

    @tx.setter
    def tx(self, tx):
        self._tx = bool(tx)

        self.update_configuration()

    @pyqtProperty(str)
    def box_title(self):
        return self.ui.box.title()

    @box_title.setter
    def box_title(self, title):
        self.ui.box.setTitle(title)

    @pyqtProperty(int)
    def quantity(self):
        return self._quantity

    @quantity.setter
    def quantity(self, quantity):
        self._quantity = quantity

        self.update_configuration()

    @pyqtProperty(str)
    def status_frame(self):
        return self._status_frame

    @status_frame.setter
    def status_frame(self, frame):
        self._status_frame = frame

        self.update_configuration()

    @pyqtProperty(str)
    def status_signal_format(self):
        return self._status_signal_format

    @status_signal_format.setter
    def status_signal_format(self, signal_format):
        self._status_signal_format = signal_format

        self.update_configuration()

    @pyqtProperty(str)
    def set_frame(self):
        return self._set_frame

    @set_frame.setter
    def set_frame(self, frame):
        self._set_frame = frame

        self.update_configuration()

    @pyqtProperty(str)
    def set_signal_format(self):
        return self._set_signal_format

    @set_signal_format.setter
    def set_signal_format(self, signal_format):
        self._set_signal_format = signal_format

        self.update_configuration()

    @pyqtProperty(str)
    def override_frame(self):
        return self._override_frame

    @override_frame.setter
    def override_frame(self, frame):
        self._override_frame = frame

        self.update_configuration()

    @pyqtProperty(str)
    def override_signal_format(self):
        return self._override_signal_format

    @override_signal_format.setter
    def override_signal_format(self, signal_format):
        self._override_signal_format = signal_format

        self.update_configuration()

    def update_configuration(self):
        while self.points:
            point = self.points.pop()
            self.ui.layout.removeWidget(point)
            point.setParent(None)

        for i in range(self.quantity):
            point = IoPoint(parent=self, in_designer=self.in_designer)
            point.index = i + 1
            point.tx = self._tx
            point.status_frame = self.status_frame
            point.status_signal = self.status_signal_format.format(point.index)
            point.set_frame = self.set_frame
            point.set_signal = self.set_signal_format.format(point.index)
            point.override_frame = self.override_frame
            point.override_signal = self.override_signal_format.format(
                point.index)
            self.ui.layout.addWidget(point)
            self.points.append(point)


if __name__ == '__main__':
    import sys

    print('No script functionality here')
    sys.exit(1)     # non-zero is a failure



# This file has been generated


build_system = 'AppVeyor'
build_id = '23435337'
build_number = '288'
build_version = '1.0.288'
job_id = 'ruoxypr180qdq05m'
job_url = 'https://ci.appveyor.com/project/KyleAltendorf/stlib/build/job/ruoxypr180qdq05m'



# import epyqlib.delegates
# import epyqlib.txrx
import io
import os
from PyQt5 import QtWidgets, uic
# from PyQt5.QtGui import QFontMetrics
from PyQt5.QtCore import QFile, QFileInfo, QTextStream, Qt
from PyQt5.QtWidgets import QHeaderView

# See file COPYING in this source tree
import epyqlib.utils.qt

__copyright__ = 'Copyright 2016, EPC Power Corp.'
__license__ = 'GPLv2+'


class VariableSelectionView(QtWidgets.QWidget):
    def __init__(self, parent=None, in_designer=False):
        QtWidgets.QWidget.__init__(self, parent=parent)

        self.in_designer = in_designer

        ui = 'variableselectionview.ui'
        # TODO: CAMPid 9549757292917394095482739548437597676742
        if not QFileInfo(ui).isAbsolute():
            ui_file = os.path.join(
                QFileInfo.absolutePath(QFileInfo(__file__)), ui)
        else:
            ui_file = ui
        ui_file = QFile(ui_file)
        ui_file.open(QFile.ReadOnly | QFile.Text)
        ts = QTextStream(ui_file)
        sio = io.StringIO(ts.readAll())
        self.ui = uic.loadUi(sio, self)

        self.ui.searchbox.connect_to_view(
            view=self.ui.tree_view,
            column=epyqlib.variableselectionmodel.Columns.indexes.name,
        )

    def set_model(self, model):
        self.ui.tree_view.setModel(model)
        model.setSortRole(epyqlib.utils.qt.UserRoles.sort)

        header = self.ui.tree_view.header()
        header.setStretchLastSection(False)
        header.setSectionResizeMode(header.ResizeToContents)

    def set_sorting_enabled(self, enabled):
        self.ui.tree_view.setSortingEnabled(enabled)

    def sort_by_column(self, column, order):
        self.ui.tree_view.sortByColumn(column, order)

    @property
    def model(self):
        return self.tree_view.model()



#!/usr/bin/env python3

#TODO: """DocString if there is one"""

import epyqlib.listmenu
import functools
import io
import math
import os
from PyQt5 import QtWidgets, uic
from PyQt5.QtGui import QPalette
from PyQt5.QtWidgets import QAbstractSlider
from PyQt5.QtCore import (pyqtSignal, pyqtSlot, QFile, QFileInfo, QTextStream,
                          QCoreApplication, QModelIndex)

# See file COPYING in this source tree
__copyright__ = 'Copyright 2016, EPC Power Corp.'
__license__ = 'GPLv2+'


class ListMenuView(QtWidgets.QWidget):
    node_clicked = pyqtSignal(epyqlib.listmenu.Node)

    def __init__(self, parent=None, in_designer=False):
        QtWidgets.QWidget.__init__(self, parent=parent)

        self.in_designer = in_designer

        ui = 'listmenuview.ui'
        # TODO: CAMPid 9549757292917394095482739548437597676742
        if not QFileInfo(ui).isAbsolute():
            ui_file = os.path.join(
                QFileInfo.absolutePath(QFileInfo(__file__)), ui)
        else:
            ui_file = ui
        ui_file = QFile(ui_file)
        ui_file.open(QFile.ReadOnly | QFile.Text)
        ts = QTextStream(ui_file)
        sio = io.StringIO(ts.readAll())
        self.ui = uic.loadUi(sio, self)

        scroll_bar = self.ui.list_view.verticalScrollBar()
        up = functools.partial(
            scroll_bar.triggerAction,
            QAbstractSlider.SliderPageStepSub
        )
        self.ui.up_button.clicked.connect(up)
        down = functools.partial(
            scroll_bar.triggerAction,
            QAbstractSlider.SliderPageStepAdd
        )
        self.ui.down_button.clicked.connect(down)

        self.ui.list_view.viewport().setAutoFillBackground(False)

        self.ui.list_view.clicked.connect(self.clicked)

    @pyqtSlot(QModelIndex)
    def clicked(self, index):
        if not index.isValid():
            return

        node = self.model.node_from_index(index)

        self.node_clicked.emit(node)

        # self.ui.module_to_nv_button.clicked.connect(self.module_to_nv)
        # self.ui.write_to_module_button.clicked.connect(self.write_to_module)
        # self.ui.read_from_module_button.clicked.connect(self.read_from_module)
        # self.ui.write_to_file_button.clicked.connect(self.write_to_file)
        # self.ui.read_from_file_button.clicked.connect(self.read_from_file)
        #
        # self.resize_columns = epyqlib.nv.Columns(
        #     name=True,
        #     value=True)

    def setModel(self, model):
        self.model = model
        self.node_clicked.connect(self.model.node_clicked)

        self.ui.list_view.setModel(self.model)

        self.ui.esc_button.clicked.connect(self.model.esc_clicked)
        self.root_changed(self.model.root)
        self.model.root_changed.connect(self.root_changed)

        # model.set_status_string.connect(self.set_status_string)

        # self.ui.module_to_nv.connect(model.module_to_nv)
        # self.ui.read_from_module.connect(model.read_from_module)
        # self.ui.write_to_module.connect(model.write_to_module)
        # self.ui.read_from_file.connect(model.read_from_file)
        # self.ui.write_to_file.connect(model.write_to_file)

        # self.ui.tree_view.header().setStretchLastSection(False)

        # for i in epyqlib.nv.Columns.indexes:
        #     if self.resize_columns[i]:
        #         self.ui.tree_view.header().setSectionResizeMode(
        #             i, QtWidgets.QHeaderView.ResizeToContents)
        # # TODO: would be nice to share between message and signal perhaps?
        # self.ui.tree_view.header().setSectionResizeMode(
        #     epyqlib.nv.Columns.indexes.value, QtWidgets.QHeaderView.Stretch)
        #
        # self.ui.tree_view.setItemDelegateForColumn(
        #     epyqlib.nv.Columns.indexes.value,
        #     epyqlib.delegates.Combo(model=model, parent=self))

    @pyqtSlot(epyqlib.listmenu.Node)
    def root_changed(self, node):
        self.ui.label.setText(node.fields.name)
        self.ui.list_view.scrollToTop()
        self.ui.esc_button.setDisabled(node.tree_parent is None)

    def set_padding(self, padding):
        self.setStyleSheet('''
            QListView::item
            {{
                padding: {}px;
            }}
        '''.format(padding))

    def update_calculated_layout(self):
        minimum_padding = 0
        self.set_padding(minimum_padding)

        view = self.ui.list_view
        model = self.model

        list = view.contentsRect().height()
        item = view.itemDelegate().sizeHint(
            view.viewOptions(),
            model.index_from_node(
                model.root)).height()
        most_items = math.floor(list / item)
        remainder = list % item
        padding = minimum_padding + (remainder / most_items) / 2
        self.set_padding(padding)

        for button in [self.ui.down_button,
                       self.ui.up_button,
                       self.ui.esc_button]:
            # TODO: CAMPid 98754713241621231778985432
            button.setMaximumWidth(button.height())

    def selected_text(self):
        indexes = self.ui.list_view.selectedIndexes()
        index = indexes[0]
        return index.internalPointer().fields.name

    def select_node(self, node):
        self.ui.list_view.setCurrentIndex(self.model.index_from_node(node))


if __name__ == '__main__':
    import sys

    print('No script functionality here')
    sys.exit(1)     # non-zero is a failure



#!/usr/bin/env python3

#TODO: """DocString if there is one"""

import functools
import io
import os

from PyQt5 import uic
from PyQt5.QtCore import pyqtProperty, QFile, QFileInfo, QTextStream
from PyQt5.QtGui import QColor
from PyQt5.QtWidgets import QLabel, QHBoxLayout, QWidget

# See file COPYING in this source tree
__copyright__ = 'Copyright 2016, EPC Power Corp.'
__license__ = 'GPLv2+'


class NumberPad(QWidget):
    def __init__(self, parent=None, in_designer=False, action=None):
        QWidget.__init__(self, parent=parent)

        self.in_designer = in_designer

        ui = os.path.join(QFileInfo.absolutePath(QFileInfo(__file__)),
                          'numberpad.ui')

        # TODO: CAMPid 9549757292917394095482739548437597676742
        if not QFileInfo(ui).isAbsolute():
            ui_file = os.path.join(
                QFileInfo.absolutePath(QFileInfo(__file__)), ui)
        else:
            ui_file = ui
        ui_file = QFile(ui_file)
        ui_file.open(QFile.ReadOnly | QFile.Text)
        ts = QTextStream(ui_file)
        sio = io.StringIO(ts.readAll())
        self.ui = uic.loadUi(sio, self)

        self.action = action
        self.ui.accept_button.clicked.connect(self.accept)
        self.ui.cancel_button.clicked.connect(
            functools.partial(self.exit, value=None))
        self.ui.up_button.clicked.connect(
            self.ui.cancel_button.clicked)

        numeric_buttons = []

        for number in range(10):
            button = getattr(self.ui, 'button_{}'.format(number))
            button.clicked.connect(
                functools.partial(
                    self.ui.edit.insert,
                    str(number)
                )
            )
            numeric_buttons.append(button)

        self.ui.button_decimal.clicked.connect(
            functools.partial(
                self.ui.edit.insert,
                '.'
            )
        )
        numeric_buttons.append(self.ui.button_decimal)

        self.ui.button_backspace.clicked.connect(self.ui.edit.backspace)

        for button in numeric_buttons:
            button.setStyleSheet('''
                QPushButton {
                    border: 0px;
                }
            ''')

    def focus(self, value, action, label=''):
        self.ui.label.setText(label)
        self.ui.edit.setText(str(value))
        self.action = action
        self.parent().setCurrentWidget(self)
        focused_widget = self.focusWidget()
        if focused_widget is not None:
            focused_widget.clearFocus()

    def accept(self):
        try:
            value = float(self.ui.edit.text())
        except ValueError:
            value = None

        self.exit(value=value)

    def exit(self, value):
        self.action(value=value)

if __name__ == '__main__':
    import sys

    print('No script functionality here')
    sys.exit(1)     # non-zero is a failure
